﻿#ifndef CHARACTER_H
#define CHARACTER_H

#include <string>
#include <vector>
#include "objects.h"
#include "../common/sources/Map.h"
#include "timer.h"

#define BACKPACK_SIZE   17

#define MANA_REGEN_TIMER        (30 * 60)
#define MANA_REGEN_TIMER_SLEEP  (4 * 60)

class CCharacter
{
public:
    enum EBodyParts
    {
        eBodyPartHead = 0,	// tête
        eBodyPartNeck,		// cou
        eBodyPartTorso,		// torse
        eBodyPartLeftHand,	// main gauche
        eBodyPartRightHand,	// main droite
        eBodyPartLegs,		// jambes
        eBodyPartFeet,		// pieds
        eBodyPartPouch1,	// poche 1
        eBodyPartPouch2,	// poche 2
        eBodyPartQuiver1,	// carquois 1
        eBodyPartQuiver2,	// carquois 2
        eBodyPartQuiver3,	// carquois 3
        eBodyPartQuiver4,	// carquois 4
        eBodyPartBackpack,	// sac à dos
        eBodyPartCount = eBodyPartBackpack + BACKPACK_SIZE
    };

    enum EStatsNames
    {
        eStatHealth = 0,
        eStatStamina,
        eStatMana,
        eStatStrength,
        eStatDexterity,
        eStatWisdom,
        eStatVitality,
        eStatAntiMagic,
        eStatAntiFire,
        eStatLoad,
        eStatCount
    };

    struct SStat
    {
        int value;
        int maxValue;
        int startValue;
    };

    CCharacter();
    bool    isDead();
    void    fromDB(int num);
    void    updateLoad();
    int     overload();
    void    load(FILE* handle);
    void    save(FILE* handle);
    void    update();
    void    enterSleep();
    void    exitSleep();
    int     getDexterity();
    void    hitChampion(int damages);

    static void    readCharactersDB();

    int         portrait;
    std::string firstName;
    std::string lastName;
    SStat       stats[eStatCount];
    CObject     bodyObjects[eBodyPartCount];
    char        spell[5];
    int         displayedDamages;   // dégats affichés sur le nom du personnage
    CTimer      damagesTimer;

private:
    struct SDBObject
    {
        int pos;
        int type;
    };

    struct SChampDBData
    {
        std::string firstName;
        std::string lastName;
        int     portrait;
        int     stats[eStatCount];
        std::vector<SDBObject>  objects;
    };

    static std::vector<SChampDBData>   dataBase;
    CTimer  manaRegenTimer;
};

#endif // CHARACTER_H
